@@ -5,6 +5,9 @@
 #' @importFrom stats sd
 #' @export
 #' @keywords internal
+#' @return An object \code{summary.bootDominanceAnalysis}, that contains
+#'         data frames with bootstrap summary statistics for each fit index
+
 
 summary.bootDominanceAnalysis<-function(object,fit.functions=NULL,...) {
 	out<-list()
@@ -21,21 +24,21 @@ summary.bootDominanceAnalysis<-function(object,fit.functions=NULL,...) {
 	m.names[,1]<-replaceTermsInString(string = m.names[,1], object$terms)
   m.names[,2]<-replaceTermsInString(string = m.names[,2], object$terms)
 	for(an in c("complete","conditional","general")) {
-		for(ff in fit.functions) {
+		for(ff in object$fit.functions) {
 		  for(m in 1:mm.n) {
-			boot.t<-object$boot$t[,ii]
-			m.out[[ii]]<-list(f=ff, dominance=an, i=m.names[m,1], k=m.names[m,2],
-			                  Dij=object$boot$t0[ii], mDij=mean(boot.t), `SE.Dij`=sd(boot.t),
-			                  Pij=sum(boot.t==1)/object$R, Pji=sum(boot.t==0)/object$R,
-			                  Pnoij=sum(boot.t==0.5) / object$R,
-			                  Rep=sum(boot.t==object$boot$t0[ii]) / object$R )
-			ii<-ii+1
+  			boot.t<-object$boot$t[,ii]
+  			m.out[[ii]]<-list(f=ff, dominance=an, i=m.names[m,1], k=m.names[m,2],
+  			                  Dij=object$boot$t0[ii], mDij=mean(boot.t), `SE.Dij`=sd(boot.t),
+  			                  Pij=sum(boot.t==1)/object$R, Pji=sum(boot.t==0)/object$R,
+  			                  Pnoij=sum(boot.t==0.5) / object$R,
+  			                  Rep=sum(boot.t==object$boot$t0[ii]) / object$R )
+  			ii<-ii+1
 		  }
 
 		}
 	}
 	mm.out<-data.frame(do.call(rbind,m.out))
-	#print(str(mm.out))
+
 	for(ff in fit.functions) {
 			out[[ff]]<-data.frame(lapply(mm.out[mm.out[,1]==ff,-1],unlist))
 	}
@@ -43,10 +46,11 @@ summary.bootDominanceAnalysis<-function(object,fit.functions=NULL,...) {
 	out
 }
 
-# Print a summary.bootDominanceAnalysis object
-# @param x a \code{\link{summary.bootDominanceAnalysis}} object
-# @param round.digits Number of decimal places to round results
-# @param ... further arguments passed to print method
+#' Print a summary.bootDominanceAnalysis object
+#' @param x a \code{\link{summary.bootDominanceAnalysis}} object
+#' @param round.digits Number of decimal places to round results
+#' @param ... further arguments passed to print method
+#' @return an object \code{\link{summary.bootDominanceAnalysis}}
 #' @export
 #' @keywords internal
 
@@ -60,5 +64,6 @@ print.summary.bootDominanceAnalysis<-function(x,round.digits=3,...) {
 		cat("\n")
 
 	}
+	invisible(x)
 }
 
